@@ -101,11 +101,25 @@ class Notion(InDriver, OutDriver):
         def query(self, database_id, query={}):
             database_id = ensure_database_id(database_id)
             ret = []
-            results = self.client.databases.query(database_id=database_id, **query).get(
-                "results"
-            )
-            for r in results:
-                ret.append(from_dict(data_class=Page, data=r))
+            has_more = True
+            next_cursor = None
+
+            while has_more:
+                if has_more is True and next_cursor is not None:
+                    query["start_cursor"] = next_cursor
+
+                response = self.client.databases.query(database_id=database_id, **query)
+                results = response.get("results")
+
+                for r in results:
+                    ret.append(from_dict(data_class=Page, data=r))
+
+                if response.get("has_more") is True:
+                    has_more = True
+                    next_cursor = response.get("next_cursor")
+                else:
+                    has_more = False
+
             return ret
 
         def create(self, db):
@@ -731,7 +745,7 @@ class Database(__BaseDataClass):
         self.properties[col_name] = DatabasePropertyFactory.new(data)
 
     def df(self):
-        pages = self.query()
+        pages = self.query({"page_size": 10})
         frames = []
 
         for page in pages:
